#!/bin/sh
#
# ******************************************************************************
# 官方网站：	www.zijidelu.org
# 服务邮箱：	service@zijidelu.org
# 作者：		刘新（网名：爱洞特漏）
# 电话：		+86-13688995218
# ------------------------------------++++
# Website:   www.zijidelu.org
# Email:     service@zijidelu.org
# Author:    Liu Xin
# Tel:       +86-13688995218
# ------------------------------------++++
# Thank you for choosing zijidelu's software!
# ******************************************************************************
#

LuManager_ver='LuManager 1.0'

LuNamp_root='/usr/local/LuNamp'
LuManager_root='/usr/local/LuManager'

color_cyan="[40;36m"
color_red="[40;31m"
color_yellow="[40;33m"
color_green="[40;32m"
color_white="[40;37m"

this_dir=`pwd`

system_hardware=`uname -m`;
uname=`uname`
server_name=`uname -n`;

if [ ! -d '/home' ]; then
	mkdir /usr/home
	ln -s /usr/home /home
fi

if [ ! -d "/home/hosts_backup" ]; then
	mkdir -p /home/hosts_backup
fi

if [ ! -d "/home/mysqls_backup" ]; then
	mkdir -p /home/mysqls_backup
fi

if [ ! -d "/home/lum_safe_files" ]; then
	mkdir -p /home/lum_safe_files
fi

if [ `uname` = 'FreeBSD' ]; then
	root_group='wheel'
	file_get='fetch'

	user_del='pw userdel';
	user_add='pw useradd';
	group_del='pw groupdel';
	group_add='pw groupadd';

	kill_all='killall';

	if [ "$system_hardware" = 'amd64' ]; then
		system_bit='64'
	else
		system_bit='32'
	fi
else
	root_group='root'
	file_get='wget -c '

	if [ -f "/usr/bin/dpkg" ] && [ "`dpkg -l |grep bash`" ]; then
		linux_type='Debian';
	else
		linux_type='RedHat';
	fi

	if [ "$system_hardware" = 'x86_64' ]; then
		system_bit='64'
	else
		system_bit='32'
	fi

	user_del='userdel';
	user_add='useradd';
	group_del='groupdel';
	group_add='groupadd';

	kill_all='skill -KILL';
fi

if [ "$system_bit" = '32' ]; then
	system_jg='i386'
else
	system_jg='x86_64'
fi

showmsg () {
	NO3_var=$3
	NO4_var=$4

	if [ ! "$NO3_var" ]; then
		NO3_var=$color_yellow
	fi

	if [ ! "$NO4_var" ]; then
		NO4_var=$color_white
	fi

	echo
	echo $NO3_var$1$NO4_var
	if [ "$2" ]; then
		echo $NO3_var$2$NO4_var
	fi
	echo
}

cc () {
	chown -R $2 $3
	chmod -R $1 $3
}

repair_files_permission() {
	if [ "$1" ]; then
		#1.0.15以下版本
		cc    '0700'    "LuManager:LuManager"    "$LuManager_root"
	else
		cc    '0500'    "LuManager:LuManager"    "$LuManager_root"
		cc    '0700'    "LuManager:LuManager"    "${LuManager_root}/Conf"
		cc    '0700'    "LuManager:LuManager"    "${LuManager_root}/Runtime"
	fi

	cc    '570'     "root:LuManager"    "$LuNamp_root"
	
	cc    '2770'    "lu_mysql:lu_mysql"    "/home/mysql_data"

	cc    '4550'    "root:LuManager"    "$LuNamp_root/cmd/L3.sh"
	cc    '4550'    "root:LuManager"    "$LuNamp_root/cmd/L6.sh"
	cc    '4550'    "root:LuManager"    "$LuNamp_root/cmd/F3.sh"
	cc    '4550'    "root:LuManager"    "$LuNamp_root/cmd/F6.sh"
}

if [ `id -u` != "0" ]; then
	showmsg    "请用root用户安装LuManager（请在命令行输入：su root）！"    "Please use root user to install LuManager (cmd: su root)!"
	exit;
fi

# 1. s
# 2. r
# 3. file
# 4. remove backup file
str_replace () {
	sed "s/$1/$2/g" $3 > ${3}.bak
	sed "s/------------search--------------/------------replace--------------/g" ${3}.bak > ${3}
	if [ "$4" ]; then
		rm -rf ${3}.bak
	fi
}


install_LuNamp() {
	if [ -f "/tmp/update_LuNamp.lock" ] || [ ! -d "${LuNamp_root}/cmd" ] || [ ! -d "${LuNamp_root}/pm" ]; then
		#1. 当没有安装过LuNamp时
		#2. $2不等于source时
		#3. 不为redhat系列系统
		if [ ! -f "/usr/local/LuNamp/cmd/lu-start" ] && [ "$linux_type" = 'RedHat' ] && [ "$2" != 'source' ]; then
			#-----------------------------判断是否用rpm包安装
			showmsg "要使用rpm包来安装LuNamp吗(安装速度更快)？[Y/n]"    "Do you want use RPM package to install LuNamp(faster)? [Y/n]"
			read use_rpm
			if [ "$use_rpm" = '' ] || [ "$use_rpm" = 'y' ] || [ "$use_rpm" = 'Y' ]; then
				if [ ! -f "LuNamp_last.${system_jg}.rpm" ]; then
					$file_get http://down.zijidelu.org/LuNamp_last.${system_jg}.rpm
					if [ ! -f "LuNamp_last.${system_jg}.rpm" ]; then
						showmsg    "LuNamp_last.${system_jg}.rpm下载失败"    "Can't to download LuNamp_last.${system_jg}.rpm"
						exit;
					fi
				fi

				if [ -f "LuNamp_last.${system_jg}.rpm" ]; then
					yum $1 install gcc gcc-c++ bzip2 make vixie-cron flex ncurses-devel wget patch ntp libxml2 libxml2-devel libevent m4 autoconf zip unzip libjpeg libjpeg-devel gd gd-devel freetype freetype-devel libpng libpng-devel openssl openssl-devel perl
					rpm -ivh LuNamp_last.${system_jg}.rpm --nodeps --force
				else
					showmsg    "LuNamp_last.${system_jg}.rpm下载失败"    "Can't to download LuNamp_last.${system_jg}.rpm"
				fi
			else
				if [ "$1" ]; then
					install_LuNamp $1 'source'
				else
					install_LuNamp    ''    'source'
				fi
			fi
		else
			#-----------------------------源码安装
			if [ ! -f "./LuNamp_last.tar.gz" ] && [ ! -d "./LuNamp" ]; then
				showmsg    "开始下载LuNamp"    "Starting download LuNamp"
				sleep 2
				$file_get http://down.zijidelu.org/LuNamp_last.tar.gz
			
				if [ ! -e "./LuNamp_last.tar.gz" ]; then
					showmsg    "LuNamp下载失败"    "Can't to download LuNamp_last.tar.gz"
					exit
				fi
			fi

			#如果已经解压过了，直接用解压包（与LuManager的安装方法相反）
			if [ -f "./LuNamp_last.tar.gz" ] && [ ! -d './LuNamp' ]; then
				showmsg    "开始解压LuNamp_last.tar.gz"    "Starting uncompress LuNamp_last.tar.gz"
				sleep 2
				tar -zxvf LuNamp_last.tar.gz
			fi

			cd LuNamp
			cp -R ./code/cmd/* ${LuNamp_root}/cmd/
			./i.sh $1
		fi
		
	fi

	echo

	if [ ! -d "${LuNamp_root}/cmd" ] || [ ! -d "${LuNamp_root}/pm" ]; then
		showmsg    "LuNamp安装失败"    "LuNamp was install failed"
		exit;
	fi
}

install_LuManager () {
	if [ -e '/tmp/LuNamp_install_status.txt' ]; then
		showmsg    "LuNamp安装失败（`cat /tmp/LuNamp_install_status.txt`）"    "The LuNamp is not installed!(`cat /tmp/LuNamp_install_status.txt`)"
		exit;
	fi

	cd $this_dir

	if [ ! -e "./LuManager_last.tar.gz" ] && [ ! -d "./LuManager" ]; then
		showmsg    "开始下载LuManager"    "Starting download LuManager"
		sleep 2
		if [ "$1" ]; then
			$file_get http://down.zijidelu.org/lum$1/LuManager_last.tar.gz
		else
			$file_get http://down.zijidelu.org/LuManager_last.tar.gz
		fi
		
		#如果指定了版分号却没文件
		if [ ! -e "./LuManager_last.tar.gz" ]; then
			$file_get http://down.zijidelu.org/LuManager_last.tar.gz
		fi
		
		if [ ! -e "./LuManager_last.tar.gz" ]; then
			showmsg    "LuManager下载失败"    "Can't to download LuManager"
			exit
		fi
	fi

	if [ -f "./LuManager_last.tar.gz" ]; then
		rm LuManager
		tar -zxvf LuManager_last.tar.gz
	fi

	mkdir -p $LuManager_root
	if [ -d "./LuManager/" ]; then
		backup_file=/home/hosts_backup/LuManager_`date +"%Y%m%d%s"`
		mkdir -p $backup_file
		cp -R $LuManager_root/* $backup_file/
		if [ -f "$LuManager_root/Conf/config.php" ]; then
			cat $LuManager_root/Conf/config.php > /home/lum_safe_files/config.php.last
			cc    '0500'    "LuManager:LuManager"    "/home/lum_safe_files/config.php.last"
		fi

		rm -rf $LuManager_root
		cp -R ./LuManager    /usr/local/
		ln -s $LuNamp_root/pm $LuManager_root/pm
	else
		showmsg 'LuManager目录不存在，LuManager安装失败！';
		exit;
	fi
	
	if [ -e "/usr/local/LuManager/Common/L3.sh" ]; then
		cp -R /usr/local/LuManager/Common/*.sh /usr/local/LuNamp/cmd/
	fi
	if [ -e "/usr/local/LuNamp/cmd/F3.sh" ]; then
		rm -rf /usr/local/LuManager/Common/*.sh
	fi
}

ai_ntpdate () {
	ntpdate time.zijidelu.org
	datetime=`date +"%Y%m%d"`
	release_date=$(($release_date-1));#wrong date time, But can be used.
	if test $datetime -lt $release_date; then
		#showmsg "您的系统时钟错误（${datetime}），请用date命令调整时间"    "Your system clock is wrong(${datetime}), Please use date command change it!"
		#showmsg "FreeBSD like this: date 201012050000(YmdHi), Linux like this: date 12050000(mdHiY)"
		#exit;

		if [ `uname` = 'FreeBSD' ]; then
			date ${release_y}${release_md}2359
		else
			date ${release_md}2359${release_y}
		fi
	fi
}

#-----------------------------------------------------------------------------------------mysql密码
check_mysql_password() {
	if [ ! `ps -Af | grep -c 'mysqld'` -gt 1 ]; then
		$LuNamp_root/cmd/lu-start
	fi

	TF="`/usr/local/mysql/bin/mysqladmin -uroot -pzijidelu extended-status|grep '+----'`"
	if [ ! "$TF" ]; then
		showmsg    "请输入您的MySQL的root用户密码!"    "Please enter the mysql root user password!"
		while [ 1 ]; do
			read mysql_password
			TF=`/usr/local/mysql/bin/mysqladmin -uroot -p${mysql_password} extended-status|grep '+----'`
			if [ "$TF" ]; then
				break
			else
				showmsg    "密码错误，请重试!"    "The password is wrong, Please retry!"
				continue;
			fi
		done
	else
		mysql_password='zijidelu'
	fi
}

import_data() {
	if [ -d '/usr/local/mysql/var/mysql' ] && [ ! -d '/home/mysql_data/mysql' ]; then
		./sh/copy_mysql_data.sh
	fi

	#备份数据库
	if [ -f '/home/mysql_data/LuManager/lu_settings.frm' ]; then
		showmsg    "LuManager的数据库已经存在，您要删除旧数据？[y/N]"    "The LuManager data(MySQL) is exists, Do you want to delete it?[y/N]"
		read delete_LuManager_data
		if [ "$delete_LuManager_data" = 'y' ] || [ "$delete_LuManager_data" = 'Y' ]; then
			mkdir -p /home/mysqls_backup
			backup_file=/home/mysqls_backup/LuManager_`date +"%Y%m%d%s"`
			mkdir -p $backup_file
			cp -R /home/mysql_data/LuManager/* $backup_file/
			
			rm -rf /home/mysql_data/LuManager/*
			showmsg    "旧的LuManager数据库备份文件：$backup_file"    "The old LuManager database backup file: $backup_file"
			sleep 1
		fi
	fi

	/usr/local/mysql/bin/mysqladmin -uroot -p${mysql_password} refresh

	if [ ! -f '/home/mysql_data/LuManager/lu_settings.frm' ]; then
		#导入刚下载的LuManager中的sql数据
		/usr/local/mysql/bin/mysql -uroot -p${mysql_password} LuManager < LuManager/LuManager.sql
		sleep 5
	fi

	if [ ! -f '/home/mysql_data/LuManager/lu_settings.frm' ]; then
		showmsg 'LuManager数据导入不成功！'    'LuManager data was not imported！'    $color_red    $color_white
		exit
	fi
}

